==> dotnet8_8.0.121-8.0.21.orig.tar.xz: src/runtime/src/coreclr/tools/aot/ILCompiler.TypeSystem.Tests/CoreTestAssembly/VirtualFunctionOverride.cs <==
﻿// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.

using System;

namespace VirtualFunctionOverride
{
    interface IIFaceWithGenericMethod
    {
        void GenMethod<T>();
    }

    class HasMethodInterfaceOverrideOfGenericMethod : IIFaceWithGenericMethod
    {
        void IIFaceWithGenericMethod.GenMethod<T>() { }
    }

    class SimpleGeneric<T>
    {
        public override string ToString()
        {
            return null;
        }
    }

    class BaseGenericWithOverload<T>
    {
        public virtual void MyMethod(string s) { }
        public virtual void MyMethod(T s) { }
    }

    class DerivedGenericWithOverload<U> : BaseGenericWithOverload<U>
    {
        public override void MyMethod(string s) { }
        public override void MyMethod(U s) { }
    }

    class ClassWithFinalizer
    {
        ~ClassWithFinalizer()
        {

        }
    }

    unsafe class FunctionPointerOverloadBase
    {
        // Do not reorder these, the test assumes this order
        public virtual Type Method(delegate* unmanaged[Cdecl]<void> p) => typeof(delegate* unmanaged[Cdecl]<void>);
        public virtual Type Method(delegate* unmanaged[Stdcall]<void> p) => typeof(delegate* unmanaged[Stdcall]<void>);
        public virtual Type Method(delegate* unmanaged[Stdcall, SuppressGCTransition]<void> p) => typeof(delegate* unmanaged[Stdcall, SuppressGCTransition]<void>);
        public virtual Type Method(delegate*<void> p) => typeof(delegate*<void>);
    }

    unsafe class FunctionPointerOverloadDerived : FunctionPointerOverloadBase
    {
        // Do not reorder these, the test assumes this order
        public override Type Method(delegate* unmanaged[Cdecl]<void> p) => null;
        public override Type Method(delegate* unmanaged[Stdcall]<void> p) => null;
        public override Type Method(delegate* unmanaged[Stdcall, SuppressGCTransition]<void> p) => null;
        public override Type Method(delegate*<void> p) => null;
    }
}

==> dotnet10_10.0.100-10.0.0~rc2.orig.tar.xz: src/runtime/src/coreclr/tools/aot/ILCompiler.TypeSystem.Tests/CoreTestAssembly/VirtualFunctionOverride.cs <==
﻿// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.

using System;

namespace VirtualFunctionOverride
{
    interface IIFaceWithGenericMethod
    {
        void GenMethod<T>();
    }

    class HasMethodInterfaceOverrideOfGenericMethod : IIFaceWithGenericMethod
    {
        void IIFaceWithGenericMethod.GenMethod<T>() { }
    }

    class SimpleGeneric<T>
    {
        public override string ToString()
        {
            return null;
        }
    }

    class BaseGenericWithOverload<T>
    {
        public virtual void MyMethod(string s) { }
        public virtual void MyMethod(T s) { }
    }

    class DerivedGenericWithOverload<U> : BaseGenericWithOverload<U>
    {
        public override void MyMethod(string s) { }
        public override void MyMethod(U s) { }
    }

    class ClassWithFinalizer
    {
        ~ClassWithFinalizer()
        {

        }
    }

    unsafe class FunctionPointerOverloadBase
    {
        // Do not reorder these, the test assumes this order
        public virtual Type Method(delegate* unmanaged[Cdecl]<void> p) => typeof(delegate* unmanaged[Cdecl]<void>);
        public virtual Type Method(delegate* unmanaged[Stdcall]<void> p) => typeof(delegate* unmanaged[Stdcall]<void>);
        public virtual Type Method(delegate* unmanaged[Stdcall, SuppressGCTransition]<void> p) => typeof(delegate* unmanaged[Stdcall, SuppressGCTransition]<void>);
        public virtual Type Method(delegate*<void> p) => typeof(delegate*<void>);
    }

    unsafe class FunctionPointerOverloadDerived : FunctionPointerOverloadBase
    {
        // Do not reorder these, the test assumes this order
        public override Type Method(delegate* unmanaged[Cdecl]<void> p) => null;
        public override Type Method(delegate* unmanaged[Stdcall]<void> p) => null;
        public override Type Method(delegate* unmanaged[Stdcall, SuppressGCTransition]<void> p) => null;
        public override Type Method(delegate*<void> p) => null;
    }

    class BaseCovariant
    {
        public virtual BaseCovariant FromType()
        {
            return new BaseCovariant();
        }
    }

    class ImplCovariant : BaseCovariant
    {
        public override ImplCovariant FromType()
        {
            return new ImplCovariant();
        }
    }

    class SubImplCovariant : ImplCovariant
    {
        public override SubImplCovariant FromType()
        {
            return new SubImplCovariant();
        }
    }

    class SubImplCovariant2 : ImplCovariant
    {
        public override ImplCovariant FromType()
        {
            return new ImplCovariant();
        }
    }

    class SubSubImplCovariant : SubImplCovariant2
    {
        public override SubSubImplCovariant FromType()
        {
            return new SubSubImplCovariant();
        }
    }
}
